# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x04user\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x63ommon.proto\"\xcf\x01\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x04type\x18\x05 \x01(\x0b\x32\x0e.user.UserType\x12.\n\x0fprofile_picture\x18\x06 \x01(\x0b\x32\x10.common.DocumentH\x00\x88\x01\x01\x12\x15\n\x08verified\x18\x07 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_profile_pictureB\x0b\n\t_verified\"&\n\x08UserType\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t2A\n\x0eUserController\x12/\n\x07GetUser\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_USER']._serialized_start=64
  _globals['_USER']._serialized_end=271
  _globals['_USERTYPE']._serialized_start=273
  _globals['_USERTYPE']._serialized_end=311
  _globals['_USERCONTROLLER']._serialized_start=313
  _globals['_USERCONTROLLER']._serialized_end=378
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authentication.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import user_pb2 as user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61uthentication.proto\x12\x0e\x61uthentication\x1a\x1bgoogle/protobuf/empty.proto\x1a\nuser.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"W\n\rSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"8\n\x0bJWTResponse\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0b\x32\x0e.user.UserType2\xdd\x01\n\x18\x41uthenticationController\x12\x44\n\x05Login\x12\x1c.authentication.LoginRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x46\n\x06Signup\x12\x1d.authentication.SignupRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x33\n\x0bGetUserData\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=81
  _globals['_LOGINREQUEST']._serialized_end=128
  _globals['_SIGNUPREQUEST']._serialized_start=130
  _globals['_SIGNUPREQUEST']._serialized_end=217
  _globals['_JWTRESPONSE']._serialized_start=219
  _globals['_JWTRESPONSE']._serialized_end=275
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_start=278
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_end=499
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: analyzer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61nalyzer.proto\x12\x08\x61nalyzer\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x63ommon.proto\"$\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x61pproved\x18\x02 \x01(\x08\"&\n\x05Posts\x12\x1d\n\x05posts\x18\x01 \x03(\x0b\x32\x0e.analyzer.Post2z\n\x12\x41nalyzerController\x12\x32\n\x08GetPosts\x12\x13.common.GetItemByID\x1a\x0f.analyzer.Posts\"\x00\x12\x30\n\x07GetPost\x12\x13.common.GetItemByID\x1a\x0e.analyzer.Post\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POST']._serialized_start=71
  _globals['_POST']._serialized_end=107
  _globals['_POSTS']._serialized_start=109
  _globals['_POSTS']._serialized_end=147
  _globals['_ANALYZERCONTROLLER']._serialized_start=149
  _globals['_ANALYZERCONTROLLER']._serialized_end=271
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x06\x63ommon\"%\n\x08\x44ocument\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x19\n\x0bGetItemByID\x12\n\n\x02id\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DOCUMENT']._serialized_start=24
  _globals['_DOCUMENT']._serialized_end=61
  _globals['_GETITEMBYID']._serialized_start=63
  _globals['_GETITEMBYID']._serialized_end=88
# @@protoc_insertion_point(module_scope)
